Module: LinearRegressionTrend
- Defined in:
- lib/linear_regression_trend.rb,
lib/linear_regression_trend/version.rb
Overview
And thanks to John Esser for helping figure out how to calculate the targets to stabilize a negative slope!
Defined Under Namespace
Classes: Calculator
Constant Summary collapse
- VERSION =
"1.2.0"